@@ -70,6 +70,7 @@ class Const(object):
             DEK.CONNECTION: DBEnv.CONNECTION,
             DEK.PGPASSFILE: DBEnv.PGPASS_FILE,
             DEK.NEW_DATABASE: DBEnv.NEW_DATABASE,
+            DEK.NEED_DBMSUPGRADE: DBEnv.NEED_DBMSUPGRADE,
             DEK.DUMPER: DBEnv.DUMPER,
             DEK.FILTER: DBEnv.FILTER,
             DEK.RESTORE_JOBS: DBEnv.RESTORE_JOBS,
@@ -168,6 +169,11 @@ class FileLocations(object):
         'backups',
     )
 
+    OVIRT_ENGINE_DWH_BINDIR = os.path.join(
+        PKG_DATA_DIR,
+        'bin',
+    )
+
     OVIRT_ENGINE_DB_MD5_DIR = os.path.join(
         PKG_STATE_DIR,
         'dwh_dbmd5',
@@ -181,6 +187,11 @@ class FileLocations(object):
         'Default.properties',
     )
 
+    OVIRT_DWH_VACUUM_TOOL = os.path.join(
+        OVIRT_ENGINE_DWH_BINDIR,
+        'dwh-vacuum.sh',
+    )
+
 
 @util.export
 class Stages(object):
@@ -323,6 +334,7 @@ class DBEnv(object):
     STATEMENT = 'OVESETUP_DWH_DB/statement'
     PGPASS_FILE = 'OVESETUP_DWH_DB/pgPassFile'
     NEW_DATABASE = 'OVESETUP_DWH_DB/newDatabase'
+    NEED_DBMSUPGRADE = 'OVESETUP_DWH_DB/needDBMSUpgrade'
 
     @osetupattrs(
         answerfile=True,
@@ -344,6 +356,12 @@ class DBEnv(object):
     def DISCONNECT_EXISTING_DWH(self):
         return 'OVESETUP_DWH_DB/disconnectExistingDwh'
 
+    @osetupattrs(
+        answerfile=True,
+    )
+    def DWH_VACUUM_FULL(self):
+        return 'OVESETUP_DB/dwhVacuumFull'
+
 
 @util.export
 @util.codegen
